package LATMOS::Accounts::Bases::SQL::object;

use 5.010000;
use strict;
use warnings;

use base qw(LATMOS::Accounts::Bases::Objects);

our $VERSION = (q$Rev$ =~ /^Rev: (\d+) /)[0];

=head1 NAME

LATMOS::Ad - Perl extension for blah blah blah

=head1 SYNOPSIS

  use LATMOS::Accounts::Bases;
  my $base = LATMOS::Accounts::Bases->new('unix');
  ...

=head1 DESCRIPTION

Account base access over standard unix file format.

=head1 FUNCTIONS

=cut

=head2 new(%options)

Create a new LATMOS::Ad object for windows AD $domain.

domain / server: either the Ad domain or directly the server

ldap_args is an optionnal list of arguments to pass to L<Net::LDAP>.

=cut

sub new {
    my ($class, $base, $id) = @_;
    bless({ id => $id }, $class);
}

sub db {
    return $_[0]->base->db;
}

sub quote_object_table {
    my ($self) = @_;
    my $table = $self->object_table or return;
    $self->db->quote_identifier($table);
}

sub get_field {
    my ($self, $field) = @_;
    my $sth = $self->db->prepare_cached(
        sprintf(
            q{select %s from %s where login = ?},
            $self->db->quote_identifier($field),
            $self->quote_object_table,
        )
    );
    $sth->execute($self->{id});
    my $res = $sth->fetchrow_hashref;
    $sth->finish;
    return $res->{$field};
}

sub set_fields {
    my ($self, %data) = @_;
    my @fields;
    my @vals;
    foreach my $field (keys %data) {
        # TODO check fields exists !
        push(@fields, sprintf("%s = ?", $self->db->quote_identifier($field)));
        push(@vals, $data{$field});
    }
    my $sth = $self->db->prepare_cached(
        sprintf(
            q{update %s set %s where login = ?},
            $self->quote_object_table),
            join(', ', @fields),
        )
    );
    $sth->execute(@vals, $self->{id});
}

1;

__END__

=head1 SEE ALSO

=head1 AUTHOR

Olivier Thauvin, E<lt>olivier.thauvin@latmos.ipsl.frE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008, 2009 CNRS SA/CETP/LATMOS

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.0 or,
at your option, any later version of Perl 5 you may have available.


=cut
